package com.tomtomwork.queueing.test.jmsintegrationtest;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import  java.io.IOException;
import java.io.InputStream;
import java.util.Properties;
import  java.util.Random;

import  com.google.common.collect.ImmutableList;

public class Util
{
 // === Static ================================================================
 
 private static final ImmutableList<String> MESSAGE_PAYLOAD;
 private static final Random                RNG = new Random();
 
 static
 {
  StringBuilder                 payload;
  ImmutableList.Builder<String> payloadBuilder;
  
  // Pre-create messages
  
  payloadBuilder = ImmutableList.builder();
  payload        = new StringBuilder(2048);
  
  for(int size = 0; size < 2048; size ++)
  {
   payload.setLength(0);
   for(int i = 0; i < size; i ++) payload.append((char)(' ' + RNG.nextInt(256 - ' ')));
   payloadBuilder.add(payload.toString());
  }

  MESSAGE_PAYLOAD = payloadBuilder.build();
 }
 
 // === Attributes ============================================================
 // === Constructor ===========================================================
 // === Public ================================================================
 
 /**
  * Create a message
  * @param id the message ID
  * @return the message
  */
 
 public static String createRandomMessage(long messageId)
 {
  return(String.format("%016x", messageId) + MESSAGE_PAYLOAD.get(RNG.nextInt(MESSAGE_PAYLOAD.size())));
 }
 
 /**
  * Retrieve the message ID from a message
  * @param message the message
  * @return the message ID
  */
 
 public static long getMessageID(String message)
 {
  return(Integer.parseInt(message.substring(0, 16), 16));
 }
 
 /**
  * Load a properties file
  * @param file the file reference
  * @return the properties
  * @throws FileNotFoundException 
  */
 
 public static Properties loadProperties(File file) 
 throws IOException
 {
  Properties  properties;
  InputStream inputStream;

  // Initialize JNDI

  properties  = new Properties();
  inputStream = null;

  try
  {
   inputStream = new FileInputStream(file);
   properties.load(inputStream);
  }
  finally
  {
   if(inputStream != null) try { inputStream.close(); } catch(Exception e) {}
  }

  return(properties);
 }  
 
 // === Package protected =====================================================
 // === Protected =============================================================
 // === Private ===============================================================
 // === Inner classes =========================================================
}
